@@ -42,10 +42,8 @@ void MakeMatrices(){
     for(i=0;i<256;i++)
         Ug[i]=74.2-(2384.0*i)/8192.0+8.0;
     for(i=0;i<256;i++)
-        Ub[i]=(3598.0*i)/8192.0 ;
+        UbVr[i]=(3598.0*i)/8192.0 ;
 
-    for(i=0;i<256;i++)
-        Vr[i]=(3598.0*i)/8192.0;
     for(i=0;i<256;i++)
         Vg[i]=93.8-(3013.0*i)/8192.0+8.0;
     for(i=0;i<256;i++)
